package com.caimei365.user.mapper;

import com.caimei365.user.model.dto.ClubUpdateDto;
import com.caimei365.user.model.po.UserPo;
import com.caimei365.user.model.vo.BeansHistoryVo;
import com.caimei365.user.model.vo.ClubVo;
import com.caimei365.user.model.vo.OrderCountVo;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/3/15
 */
@Mapper
public interface ClubMapper {
    /**
     * 根据Id查询机构
     *
     * @param clubId 机构Id
     * @return ClubVo
     */
    ClubVo getClubById(Integer clubId);

    /**
     * 修改机构信息保存用户
     *
     * @param user 用户数据
     */
    void updateClubUserByUpdateInfo(UserPo user);

    /**
     * 修改机构信息保存机构
     *
     * @param club 机构数据
     */
    void updateClubByUpdateInfo(ClubUpdateDto club);

    /**
     * 获取订单数量
     *
     * @param userId
     * @return
     */
    OrderCountVo getOrderCount(Integer userId);

    /**
     * 查询采美豆类型记录
     *
     * @param userId
     * @param beansType
     * @return
     */
    Integer findBeansHistoryByType(@Param("userId") Integer userId, @Param("beansType") int beansType);

    /**
     * 修改采美豆数量
     *
     * @param userId
     * @param userBeans
     */
    void updateUserBeans(@Param("userId") Integer userId, @Param("userBeans") Integer userBeans);


    /**
     * 查询未推送的采美豆记录
     *
     * @param userId
     * @return
     */
    BeansHistoryVo findBeansHistory(Integer userId);

    /**
     * 查询本状态下未推送的采美豆数量
     *
     * @param userId
     * @param beansType
     * @return
     */
    Integer findByBeansType(@Param("userId") Integer userId, @Param("beansType") int beansType);

    /**
     * 修改推送状态
     *
     * @param userId
     */
    void updatePushStatus(Integer userId);

    /**
     * 查询采美豆收支明细
     *
     * @param userId
     * @param startTime
     * @param endTime
     * @param type
     * @return
     */
    List<BeansHistoryVo> findAllBeansHistory(@Param("userId") Integer userId, @Param("startTime") String startTime, @Param("endTime") String endTime, @Param("type") Integer type);

    /**
     * 查询今天是否有登录送豆
     *
     * @param userId
     * @return
     */
    Integer findLoginBeans(Integer userId);

    /**
     * 查询机构用户可用优惠券数量
     *
     * @param userId
     * @return
     */
    Integer findCountCoupon(Integer userId);
}
